# DuckDB database files
DuckDB v0.10 enables the creation of storage database files, ensuring seamless compatibility for subsequent versions to read files generated by older versions. *Note: it is recommended to compress large database files.*

For further details, please refer to: [Storage & Compatibility](https://duckdb.org/docs/stable/internals/storage#compatibility)

### How to gzip a database file
```
gzip <filename.db>
```

### How to decompress and load a gzipped database file in the test runner
```
unzip <path/to/filename.db.gz> <extraction/path/to/filename.db>

load <extraction/path/to/filename.db> readonly
```

or by using the default extraction path `__TEST_DIR__/` (temporary space)
```
unzip <path/to/filename.db.gz>

load __TEST_DIR__/<filename.db> readonly
```
